grid

package
v0.8.73 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var AnalyticGridDatagrid datagrid.Datagrid = datagrid.Datagrid{
	Name:      "АНАЛИЗ",
	Identity:  "id",
	DataTable: "analytic",
	MainTable: "analytic",
	DataModel: new(AnalyticGrid),
	Data:      new([]AnalyticGrid),
	MainModel: new(AnalyticMainTable),
	Columns: []datagrid.Column{
		datagrid.Column{
			Model: "id",
			Label: "",
		},
		datagrid.Column{
			Model: "title",
			Label: "Нэр",
		},
		datagrid.Column{
			Model: "source",
			Label: "Хүснэгт",
		},
	},
	ColumnList:  []string{"id", "title", "source"},
	Filters:     map[string]string{},
	Relations:   []models.GridRelation{},
	Condition:   "",
	Aggregation: "",
	Triggers: map[string]interface{}{
		"beforeFetch":        "",
		"beforeFetchStruct":  new(interface{}),
		"afterFetch":         "",
		"afterFetchStruct":   new(interface{}),
		"beforeDelete":       "",
		"beforeDeleteStruct": new(interface{}),
		"afterDelete":        "",
		"afterDeleteStruct":  new(interface{}),
		"beforePrint":        "",
		"beforePrintStruct":  new(interface{}),
	},
	TriggerNameSpace: "",
}
var CrudLogDatagrid datagrid.Datagrid = datagrid.Datagrid{
	Name:      "Cистем лог",
	Identity:  "id",
	DataTable: "ds_crud_log",
	MainTable: "crud_log",
	DataModel: new(CrudLog),
	Data:      new([]CrudLog),
	MainModel: new(CrudLogMainTable),
	Columns: []datagrid.Column{
		datagrid.Column{Model: "name", Label: "Маягт"},
		datagrid.Column{Model: "last_name", Label: "Хэрэглэгчийн овог"},
		datagrid.Column{Model: "first_name", Label: "Хэрэглэгчийн нэр"},
		datagrid.Column{Model: "ip", Label: "IP хаяг"},
		datagrid.Column{Model: "user_agent", Label: "хэрэглэгчийн агент"},
		datagrid.Column{Model: "action", Label: "Үйлдэл"},
		datagrid.Column{Model: "row_id", Label: "бүртгэлийн ID"},
		datagrid.Column{Model: "input", Label: "Оролтын мэдээлэл"},
		datagrid.Column{Model: "created_at", Label: "Огноо"},
	},
	ColumnList: []string{"id", "name", "last_name", "first_name", "ip", "user_agent", "action", "row_id", "input", "created_at"},
	Filters: map[string]string{
		"user_id": "Select",

		"schemaId": "Select",
	},
	Relations:   []models.GridRelation{},
	Condition:   "",
	Aggregation: "",
	Triggers: map[string]interface{}{
		"beforeFetch":        "",
		"beforeFetchStruct":  new(interface{}),
		"afterFetch":         "",
		"afterFetchStruct":   new(interface{}),
		"beforeDelete":       "",
		"beforeDeleteStruct": new(interface{}),
		"afterDelete":        "",
		"afterDeleteStruct":  new(interface{}),
		"beforePrint":        "",
		"beforePrintStruct":  new(interface{}),
	},
	TriggerNameSpace: "",
}
var KrudGridDatagrid datagrid.Datagrid = datagrid.Datagrid{
	Name:      "Крүд тохиргоо",
	Identity:  "ID",
	DataTable: "KRUD",
	MainTable: "KRUD",
	DataModel: new(KrudGrid),
	Data:      new([]KrudGrid),
	MainModel: new(KrudGridMain),
	Columns: []datagrid.Column{
		datagrid.Column{
			Model: "title",
			Label: "Гарчиг",
		},
	},
	ColumnList:  []string{"ID", "TITLE"},
	Filters:     map[string]string{},
	Relations:   []models.GridRelation{},
	Condition:   "",
	Aggregation: "",
	Triggers: map[string]interface{}{
		"beforeFetch":        "",
		"beforeFetchStruct":  new(interface{}),
		"afterFetch":         "",
		"afterFetchStruct":   new(interface{}),
		"beforeDelete":       "",
		"beforeDeleteStruct": new(interface{}),
		"afterDelete":        "",
		"afterDeleteStruct":  new(interface{}),
		"beforePrint":        "",
		"beforePrintStruct":  new(interface{}),
	},
	TriggerNameSpace: "",
}
var MenuGridDatagrid datagrid.Datagrid = datagrid.Datagrid{
	Name:      "Цэсний тохиргоо",
	Identity:  "id",
	DataTable: "vb_schemas",
	MainTable: "vb_schemas",
	DataModel: new(MenuGrid),
	Data:      new([]MenuGrid),
	MainModel: new(MenuGridMain),
	Columns: []datagrid.Column{
		datagrid.Column{Model: "name", Label: "Нэр"},
		datagrid.Column{Model: "created_at", Label: "Огноо"},
	},
	ColumnList:  []string{"id", "name", "created_at"},
	Filters:     map[string]string{},
	Relations:   []models.GridRelation{},
	Condition:   "type = 'menu'",
	Aggregation: "",
	Triggers: map[string]interface{}{
		"beforeFetch":        "",
		"beforeFetchStruct":  new(interface{}),
		"afterFetch":         "",
		"afterFetchStruct":   new(interface{}),
		"beforeDelete":       "",
		"beforeDeleteStruct": new(interface{}),
		"afterDelete":        "",
		"afterDeleteStruct":  new(interface{}),
		"beforePrint":        "",
		"beforePrintStruct":  new(interface{}),
	},
	TriggerNameSpace: "",
}
var NotificationTargetDatagrid datagrid.Datagrid = datagrid.Datagrid{
	Name:      "Зорилтод мэдэгдэл",
	Identity:  "id",
	DataTable: "notification_targets",
	MainTable: "notification_targets",
	DataModel: new(NotificationTarget),
	Data:      new([]NotificationTarget),
	MainModel: new(NotificationTargetMainTable),
	Columns: []datagrid.Column{
		datagrid.Column{Model: "title", Label: "Нэр"},
	},
	ColumnList:  []string{"id", "title"},
	Filters:     map[string]string{},
	Relations:   []models.GridRelation{},
	Condition:   "",
	Aggregation: "",
	Triggers: map[string]interface{}{
		"beforeFetch":        "",
		"beforeFetchStruct":  new(interface{}),
		"afterFetch":         "",
		"afterFetchStruct":   new(interface{}),
		"beforeDelete":       "",
		"beforeDeleteStruct": new(interface{}),
		"afterDelete":        "",
		"afterDeleteStruct":  new(interface{}),
		"beforePrint":        "",
		"beforePrintStruct":  new(interface{}),
	},
	TriggerNameSpace: "",
}

Functions

This section is empty.

Types

type AnalyticGrid

type AnalyticGrid struct {
	ID     int    `gorm:"column:id;primaryKey;autoIncrement" json:"id"`
	Source string `gorm:"column:source" json:"source"`
	Title  string `gorm:"column:title" json:"title"`
}

func (*AnalyticGrid) TableName

func (a *AnalyticGrid) TableName() string

TableName sets the insert table name for this struct type

type AnalyticMainTable

type AnalyticMainTable struct {
	ID     int    `gorm:"column:id;primaryKey;autoIncrement" json:"id"`
	Source string `gorm:"column:source" json:"source"`
	Title  string `gorm:"column:title" json:"title"`
}

func (*AnalyticMainTable) TableName

func (a *AnalyticMainTable) TableName() string

type CrudLog

type CrudLog struct {
	Action    string     `gorm:"column:ACTION" json:"action"`
	CreatedAt *time.Time `gorm:"column:CREATED_AT" json:"created_at"`
	FirstName string     `gorm:"column:FIRST_NAME" json:"first_name"`
	ID        int        `gorm:"column:ID" json:"id"`
	Input     string     `gorm:"column:INPUT" json:"input"`
	IP        string     `gorm:"column:IP" json:"ip"`
	LastName  string     `gorm:"column:LAST_NAME" json:"last_name"`
	Name      string     `gorm:"column:NAME" json:"name"`
	RowID     string     `gorm:"column:ROW_ID" json:"row_id"`
	UserAgent string     `gorm:"column:USER_AGENT" json:"user_agent"`
}

func (*CrudLog) TableName

func (d *CrudLog) TableName() string

TableName sets the insert table name for this struct type

type CrudLogMainTable

type CrudLogMainTable struct {
	Action    string     `gorm:"column:action" json:"action"`
	CreatedAt *time.Time `gorm:"column:created_at" json:"created_at"`
	ID        int        `gorm:"column:id;primaryKey;autoIncrement" json:"id"`
	Input     string     `gorm:"column:input" json:"input"`
	IP        string     `gorm:"column:ip" json:"ip"`
	RowID     string     `gorm:"column:row_id" json:"row_id"`
	SchemaID  int        `gorm:"column:schemaId" json:"schemaId"`
	UserAgent string     `gorm:"column:user_agent" json:"user_agent"`
	UserID    int        `gorm:"column:user_id" json:"user_id"`
}

func (*CrudLogMainTable) TableName

func (m *CrudLogMainTable) TableName() string

type KrudGrid

type KrudGrid struct {
	ID        int            `gorm:"column:ID;primaryKey;autoIncrement" json:"id"`
	Actions   *string        `gorm:"column:ACTIONS" json:"actions"`
	Form      *int           `gorm:"column:FORM" json:"form"`
	Grid      *int           `gorm:"column:GRID" json:"grid"`
	Template  *string        `gorm:"column:TEMPLATE" json:"template"`
	Title     *string        `gorm:"column:TITLE" json:"title"`
	CreatedAt *time.Time     `gorm:"column:CREATED_AT" json:"created_at"`
	UpdatedAt *time.Time     `gorm:"column:UPDATED_AT" json:"updated_at"`
	DeletedAt gorm.DeletedAt `gorm:"column:DELETED_AT" json:"-"`
}

func (*KrudGrid) TableName

func (k *KrudGrid) TableName() string

type KrudGridMain

type KrudGridMain struct {
	ID        int            `gorm:"column:ID;primaryKey;autoIncrement" json:"id"`
	Actions   *string        `gorm:"column:ACTIONS" json:"actions"`
	Form      *int           `gorm:"column:FORM" json:"form"`
	Grid      *int           `gorm:"column:GRID" json:"grid"`
	Template  *string        `gorm:"column:TEMPLATE" json:"template"`
	Title     *string        `gorm:"column:TITLE" json:"title"`
	CreatedAt *time.Time     `gorm:"column:CREATED_AT" json:"created_at"`
	UpdatedAt *time.Time     `gorm:"column:UPDATED_AT" json:"updated_at"`
	DeletedAt gorm.DeletedAt `gorm:"column:DELETED_AT" json:"-"`
}

func (*KrudGridMain) TableName

func (k *KrudGridMain) TableName() string
type MenuGrid struct {
	ID        int        `gorm:"column:ID;primaryKey;autoIncrement" json:"id"`
	Name      string     `gorm:"column:NAME" json:"name"`
	Schema    string     `gorm:"column:SCHEMA;type:LONG" json:"schema"`
	Type      string     `gorm:"column:TYPE" json:"type"`
	CreatedAt *time.Time `gorm:"column:CREATED_AT" json:"created_at"`
	UpdatedAt *time.Time `gorm:"column:UPDATED_AT" json:"updated_at"`
}
func (v *MenuGrid) TableName() string

TableName sets the insert table name for this struct type

type MenuGridMain struct {
	ID        int        `gorm:"column:ID;primaryKey;autoIncrement" json:"id"`
	Name      string     `gorm:"column:NAME" json:"name"`
	Schema    string     `gorm:"column:SCHEMA;type:LONG" json:"schema"`
	Type      string     `gorm:"column:TYPE" json:"type"`
	CreatedAt *time.Time `gorm:"column:CREATED_AT" json:"created_at"`
	UpdatedAt *time.Time `gorm:"column:UPDATED_AT" json:"updated_at"`
}
func (v *MenuGridMain) TableName() string

TableName sets the insert table name for this struct type

type NotificationTarget

type NotificationTarget struct {
	ID    int    `gorm:"column:ID;primaryKey;autoIncrement" json:"id"`
	Title string `gorm:"column:TITLE" json:"title"`
}

func (*NotificationTarget) TableName

func (n *NotificationTarget) TableName() string

TableName sets the insert table name for this struct type

type NotificationTargetMainTable

type NotificationTargetMainTable struct {
	Body      string `gorm:"column:BODY" json:"body"`
	Condition string `gorm:"column:CONDITION" json:"condition"`
	ID        int    `gorm:"column:ID;primaryKey;autoIncrement" json:"id"`
	Link      string `gorm:"column:LINK" json:"link"`
	SchemaID  int    `gorm:"column:SCHEMA_ID" json:"schema_id"`

	TargetRole int    `gorm:"column:TARGET_ROLE" json:"target_role"`
	Title      string `gorm:"column:TITLE" json:"title"`
}

func (*NotificationTargetMainTable) TableName

func (n *NotificationTargetMainTable) TableName() string

Jump to